#
# spec file for package python-pyvo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pyvo
Version:        1.5.2
Release:        1.2
Summary:        Astropy affiliated package for accessing Virtual Observatory data and services
License:        BSD-3-Clause
URL:            https://github.com/astropy/pyvo
Source:         https://files.pythonhosted.org/packages/source/p/pyvo/pyvo-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module astropy >= 4.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-astropy-header}
BuildRequires:  %{python_module pytest-doctestplus}
BuildRequires:  %{python_module pytest-remotedata}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module requests}
# /SECTION
BuildRequires:  fdupes
Requires:       python-astropy >= 4.1
Requires:       python-requests
Suggests:       python-pillow
Suggests:       python-sphinx-astropy
Suggests:       python-pytest-astropy
Suggests:       python-requests-mock
BuildArch:      noarch
%python_subpackages

%description
Astropy affiliated package for accessing Virtual Observatory data and services

%prep
%setup -q -n pyvo-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.rst
%{python_sitelib}/pyvo
%{python_sitelib}/pyvo-%{version}.dist-info

%changelog
* Fri Aug 16 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.5.2:
  * Bug Fixes
    + Avoid Astropy Time error for SIAResult.dateobs when VOX:Image_MJDateObs
    or ssa:DataID.Date is nan.
    + More robust handling of SIA1 FORMAT
    + Fix pyvo.registry.Author to allow registry searches with author
    constraints.
    + Backing out of having alt_identifier in RegistryResource throughout.
    Use get_alt_identifier() instead
    + Fix maxrec=0 special case for SIA2 queries.
    + Fixed TapResults to inherit session.
    + Fix handling of nan values for Time properties in SIA2 records.
    + Fix SIA2 search to accept SkyCoord position inputs.
    + Favouring VOX:Image_AccessReference for data url for SIA1 queries.
  * Enhancements and Fixes
    + registry.search now allows programmatic selection of the registry TAP
    service endpoint with the choose_RegTAP_service function.
    + registry.search now introspects the TAP service's capabilities and only
    offers extended functionality or optimisations if the required features
    are present
    + Registry search now finds SIA v2 services.
    + Made SIA2Service accept access urls without finding them in the service
    capabilities.
    + Fix session inheritance in SIA2.
    + Add intersect modes for the spatial constraint in the registry module
    pyvo.registry.Spatial.
    + Added alt_identifier, created, updated and rights to the attributes of
    pyvo.registry.regtap.RegistryResource
    + Added the source_value and alt_identifier information to the verbose
    output of describe() in regtap.
    + Added convenience method DALResults.to_qtable() that returns an
    astropy.table.QTable object.
    + TAP examples now support the continuation property.
    + Fix poor polling behavior when running an async query against a
    TAP v1.1 service with unsupported WAIT parameter.
    + Adding python version to User-Agent.
    + Output of repr for DALResults instance now clearly shows it is a
    DALResultsTable and not a generic astropy Table.
    + Adding support for the VODataService 1.2 nrows attribute on table
    elements.
  * Deprecations and Removals
    + Classes SIAService, SIAQuery, SIAResults for SIA v2 have been renamed
    to SIA2Service, SIA2Query, SIA2Results respectively as well as the
    variable SIA_PARAMETERS_DESC to SIA2_PARAMETERS_DESC.
    + Class pyvo.vosi.vodataservice.Table has been renamed to
    VODataServiceTable to avoid sharing the name with a more generic
    astropy.table.Table while having different API.
    + Deprecate VOSI AvailabilityMixin, this mean the deprecation of the
    inherited availability, available, and up_since properties of DAL
    service classes, too.
    + Deprecating ivoid2service because it is ill-defined.
- Switch to pyproject macros.
* Sun Apr  9 2023 Matwey Kornilov <matwey.kornilov@gmail.com>
- Initial version
